%Example program for the DataqSDK.NET control with a DI-1100 in MATLAB. 
%Prerequisites: WinDaq software installed, DI-1100 hardware installed,
%DATAQ SDK installation must be newer than 12/8/17.
%Please submit any questions about this program online at: http://www.dataq.com/ticket/

%Make the .NET DATAQ SDK assembly visible to MATLAB
%The file path for the .dll's will vary depending on your OS and installation version.  
%The dll's will only need to be added the first time you run the program
NET.addAssembly('C:\Windows\Microsoft.NET\assembly\GAC_MSIL\Dataq\v4.0_2.1.0.0__9767f47f9c295223\Dataq.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices.Main\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.Main.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Platforms\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Platforms.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Protocols\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Protocols.dll');

%Locate your DI-1100 by the Serial Number
%CHANGE SERIAL NUMBER TO THE SERIAL NUMBER ON THE BOTTOM OF YOUR DEVICE
DIHardware = Dataq.Misc.Discovery.BySerialAsync('58D27FE9');

%Connect to your DI-1100
myDI1100 = DIHardware.Result;
try
    myDI1100.ConnectAsync.Result;
catch ME
    disp(ME.message);
end

%Display the properties and methods of the Dataq.Devices.DI2108.Device
%class
properties(myDI1100)
methods(myDI1100)

%Display device information
disp('Manufacturer: ')
disp(myDI1100.Manufacturer)
disp('Model: ')
disp(myDI1100.Model)
disp('Serial: ')
disp(myDI1100.Serial)

%Demonstrate how to set the LED color, LED will flash blue once acquisition starts
%Red - 
myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Red)
%Black - myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Black)
%Blue - myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Blue)
%Green - myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Green)
%Cyan - myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Cyan)
%Magenta - myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Magenta)
%Yellow - myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Yellow)
%White - myDI1100.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.White)

%Initialize the device
myDI1100.Channels.Clear()

%Get supported channel types for the DI-1100
SupportedChannelTypes = myDI1100.SupportedChannels.GetEnumerator();
SupportedChannelTypes.MoveNext();
AnalogVoltageIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
DigitalIn = SupportedChannelTypes.Current.Key();

%Configure the Analog Channels
myDI1100.ChannelFactory(AnalogVoltageIn,1);
%Analog Channel 2
myDI1100.ChannelFactory(AnalogVoltageIn,2);
%Analog Channel 3
myDI1100.ChannelFactory(AnalogVoltageIn,3);
%Analog Channel 4
myDI1100.ChannelFactory(AnalogVoltageIn,4);

%Display the sample rate per channel
FirstChannel = myDI1100.Channels.Item(0);
disp('Sample Rate per Channel: ')
disp(FirstChannel.GetSampleRate(myDI1100))

%Configure the device as defined
try
    myDI1100.InitializeAsync.Result; 
catch ME
    disp(ME.message);
end

%Start scanning
try
    myDI1100.AcquisitionStartAsync.Result;
catch ME
    disp(ME.message);
end

%Define the data array
DI_TempDataArray = {};

%Set an amount of time you want to collect data until the loop exits
DIRuntime = 10; %Time in seconds to acquire data
timerID = tic;  %Start a clock and return the timer ID

%Read data and display in Command Window
while myDI1100.IsAcquiring() && (toc(timerID) < DIRuntime);
    try
        %Refresh the buffer DataIn with new data
        myDI1100.ReadDataAsync.Result;
    catch ME
        disp(ME.message);
        break
    end

%Initialize temporary array to hold new data
DI_TempDataArray = [];

%Convert .NET array data to a double array with a 
%column for each enabled channel.
        for ColumnChan = 1:myDI1100.Channels.Count
            ch = myDI1100.Channels.Item(ColumnChan-1);
            DI_NewData = ch.DataIn.ToArray;
            %DI_NewData = ch.DataIn(0).ToString;
            %temp1 = CType(ch, Dataq.Devices.IChannelIn).DataIn(index).ToString
            DI_NewData = reshape(DI_NewData.double,[],1);
            if ColumnChan == 1 
                DI_TempDataArray = DI_NewData;
            else
                DI_TempDataArray(:,ColumnChan) = DI_NewData;
            end
            %Clear data from the buffer
            ch.DataIn.Clear;
        end  
        %Display the data in the command window
        disp(DI_TempDataArray)
end

%Stop scanning
myDI1100.AcquisitionStopAsync.Result;

%It is important to disconnect from the device.  If you have connected
%successfully to the device, but do not disconnect you may need to unplug
%your hardware from the USB cable before you can connect again.
myDI1100.Dispose;
DIHardware.Dispose;



 







