%Example program for the DataqSDK.NET control with a DI-1110 in MATLAB. 
%Prerequisites: WinDaq software installed, DI-1110 hardware installed,
%DATAQ SDK installation must be newer than 12/8/17.
%Please submit any questions about this program online at: http://www.dataq.com/ticket/

%Make the .NET DATAQ SDK assembly visible to MATLAB
%The file path for the .dll's will vary depending on your OS and installation version.  
%The dll's will only need to be added the first time you run the program
NET.addAssembly('C:\Windows\Microsoft.NET\assembly\GAC_MSIL\Dataq\v4.0_2.1.0.0__9767f47f9c295223\Dataq.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices.Main\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.Main.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Platforms\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Platforms.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Protocols\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Protocols.dll');

%Locate your DI-1110 by the Serial Number
%CHANGE SERIAL NUMBER TO THE SERIAL NUMBER ON THE BOTTOM OF YOUR DEVICE
DIHardware = Dataq.Misc.Discovery.BySerialAsync('59000000');

%Connect to your DI-1110
myDI1110 = DIHardware.Result;
try
    myDI1110.ConnectAsync.Result;
catch ME
    disp(ME.message);
end

%Display the properties and methods of the Dataq.Devices.DI1110.Device
%class
properties(myDI1110)
methods(myDI1110)

%Display device information
disp('Manufacturer: ')
disp(myDI1110.Manufacturer)
disp('Model: ')
disp(myDI1110.Model)
disp('Serial: ')
disp(myDI1110.Serial)

%Demonstrate how to set the LED color, LED will flash blue once acquisition starts
%Red - 
myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Red)
%Black - myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Black)
%Blue - myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Blue)
%Green - myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Green)
%Cyan - myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Cyan)
%Magenta - myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Magenta)
%Yellow - myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Yellow)
%White - myDI1110.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.White)

%Initialize the device
myDI1110.Channels.Clear()

%Get supported channel types for the 1110. 
SupportedChannelTypes = myDI1110.SupportedChannels.GetEnumerator();
SupportedChannelTypes.MoveNext();
AnalogVoltageIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
DigitalIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
DigitalOut = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
FrequencyIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
CounterIn = SupportedChannelTypes.Current.Key();

%Configure the Analog Channels
%Analog Channel 1
myDI1110.ChannelFactory(AnalogVoltageIn,1);
%Analog Channel 2
myDI1110.ChannelFactory(AnalogVoltageIn,2);
%Analog Channel 3
myDI1110.ChannelFactory(AnalogVoltageIn,3);
%Analog Channel 4
myDI1110.ChannelFactory(AnalogVoltageIn,4);

%Display the sample rate per channel
FirstChannel = myDI1110.Channels.Item(0);
disp('Sample Rate per Channel: ')
disp(FirstChannel.GetSampleRate(myDI1110))

%Configure the device as defined
try
    myDI1110.InitializeAsync.Result; 
catch ME
    disp(ME.message);
end

%Start scanning
try
    myDI1110.AcquisitionStartAsync.Result;
catch ME
    disp(ME.message);
end

%Define the data array
DI_TempDataArray = {};

%Set an amount of time you want to collect data until the loop exits
DIRuntime = 10; %Time in seconds to acquire data
timerID = tic;  %Start a clock and return the timer ID

%Read data and display in Command Window
while myDI1110.IsAcquiring() && (toc(timerID) < DIRuntime);
    try
        %Refresh the buffer DataIn with new data
        %ReadDataAsync moves data from a small, temp buffer between USB hadrware and Windows
        %into the SDK's DataIn buffer. ReadDataAsync should be called frequently to prevent a buffer
        %overflow at the hardware level. However, buffer DataIn can grow to the size of available RAM if necessary.
        myDI1110.ReadDataAsync.Result;
    catch ME
        disp(ME.message);
        break
    end

%Initialize temporary array to hold new data
DI_TempDataArray = [];

%Convert .NET array data to a double array with a 
%column for each enabled channel.
        for ColumnChan = 1:myDI1110.Channels.Count %this is the column (channel) counter
            ch = myDI1110.Channels.Item(ColumnChan-1);
            DI_NewData = ch.DataIn.ToArray;
            %DI_NewData = ch.DataIn(0).ToString;
            %temp1 = CType(ch, Dataq.Devices.IChannelIn).DataIn(index).ToString
            DI_NewData = reshape(DI_NewData.double,[],1);
            if ColumnChan == 1 
                DI_TempDataArray = DI_NewData;
            else
                DI_TempDataArray(:,ColumnChan) = DI_NewData;
            end
            %Clear data from the buffer
            ch.DataIn.Clear;
        end  
        
        %Display the data in the command window
        disp(DI_TempDataArray)
end

%Stop scanning
myDI1110.AcquisitionStopAsync.Result;

%It is important to disconnect from the device.  If you have connected
%successfully to the device, but do not disconnect you may need to unplug
%your hardware from the USB cable before you can connect again.
myDI1110.Dispose;
DIHardware.Dispose;


 







