%Example program for the DataqSDK.NET control with a DI-2008 in MATLAB. 
%Prerequisites: WinDaq software installed, DI-2008 hardware installed,
%DATAQ SDK installation must be newer than 12/8/17.
%Please submit any questions about this program online at: http://www.dataq.com/ticket/

%Make the .NET DATAQ SDK assembly visible to MATLAB
%The file path for the .dll's will vary depending on your OS and installation version.  
%The dll's will only need to be added the first time you run the program
NET.addAssembly('C:\Windows\Microsoft.NET\assembly\GAC_MSIL\Dataq\v4.0_2.1.0.0__9767f47f9c295223\Dataq.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices.Main\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.Main.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Platforms\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Platforms.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Protocols\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Protocols.dll');

%Locate your DI-2008 by the Serial Number
%CHANGE SERIAL NUMBER TO THE SERIAL NUMBER ON THE BOTTOM OF YOUR DEVICE
DIHardware = Dataq.Misc.Discovery.BySerialAsync('59DE2236');

%Connect to your DI-2008
myDI2008 = DIHardware.Result;
try
    myDI2008.ConnectAsync.Result;
catch ME
    disp(ME.message);
end

%Display the properties and methods of the Dataq.Devices.DI2008.Device
%class
properties(myDI2008)
methods(myDI2008)

%Display device information
disp('Manufacturer: ')
disp(myDI2008.Manufacturer)
disp('Model: ')
disp(myDI2008.Model)
disp('Serial: ')
disp(myDI2008.Serial)

%Initialize the device
myDI2008.Channels.Clear();

%Demonstrate how to set the LED color, LED will flash blue once acquisition starts
%Red - 
myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Red)
%Black - myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Black)
%Blue - myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Blue)
%Green - myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Green)
%Cyan - myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Cyan)
%Magenta - myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Magenta)
%Yellow - myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Yellow)
%White - myDI2008.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.White)

%Get supported channel types for the 2008. 
SupportedChannelTypes = myDI2008.SupportedChannels.GetEnumerator();
SupportedChannelTypes.MoveNext();
AnalogVoltageIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
ThermocoupleVoltageIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
DigitalIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
DigitalOut = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
FrequencyIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
CounterIn = SupportedChannelTypes.Current.Key();

%Configure an Analog Channel
%Channel 1
AnalogChan = myDI2008.ChannelFactory(AnalogVoltageIn,1);
%Acquisition Modes:
%Dataq.Devices.DI2008.AverageSample
%Dataq.Devices.DI2008.MaximumSample
%Dataq.Devices.DI2008.MinimumSample
%Dataq.Devices.DI2008.LastSample
AnalogChan.AcquisitionMode = Dataq.Devices.DI2008.AverageSample;
AnalogChan.HardwareRange.Minimum = -1; %"1 V"
AnalogChan.HardwareRange.Maximum = 1;
AnalogChan.AcquisitionMode.Samples = 1; %Decimation factor

%Channel 2
AnalogChan = myDI2008.ChannelFactory(AnalogVoltageIn,2);
AnalogChan.AcquisitionMode = Dataq.Devices.DI2008.MaximumSample;
AnalogChan.HardwareRange.Minimum = -10; %"10 V"
AnalogChan.HardwareRange.Maximum = 10;

%Configure a thermocouple channel
%Channel 3
ThermocoupleChan = myDI2008.ChannelFactory(ThermocoupleVoltageIn,3);
ThermocoupleChan.AcquisitionMode = Dataq.Devices.DI2008.AverageSample;
ThermocoupleChan.ThermocoupleType = Dataq.Devices.DI2008.ThermocoupleTypeJ;

%Set the sample rate
myDI2008.SetSampleRateOnChannels(10)

%Display the sample rate per channel
FirstChannel = myDI2008.Channels.Item(0);
disp('Sample Rate per Channel: ')
disp(FirstChannel.GetSampleRate(myDI2008))

%Configure the device as defined
try
    myDI2008.InitializeAsync.Result; 
catch ME
    disp(ME.message);
end

%Start scanning
try
    myDI2008.AcquisitionStartAsync.Result;
catch ME
    disp(ME.message);
end

%Define the data array
DI_TempDataArray = {};

%Set an amount of time you want to collect data until the loop exits
DIRuntime = 10; %Time to acquire data
timerID = tic;  %Start a clock and return the timer ID

%Read data and display in Command Window
while myDI2008.IsAcquiring() && (toc(timerID) < DIRuntime);
    try
        %Refresh the buffer DataIn with new data
        myDI2008.ReadDataAsync.Result;
    catch ME
        disp(ME.message);
        break
    end

%Initialize temporary array to hold new data
DI_TempDataArray = [];

%Convert .NET array data to a double array with a 
%column for each enabled channel.
        for ColumnChan = 1:myDI2008.Channels.Count
            ch = myDI2008.Channels.Item(ColumnChan-1);
            DI_NewData = ch.DataIn.ToArray;
            DI_NewData = reshape(DI_NewData.double,[],1);
            if ColumnChan == 1 
                DI_TempDataArray = DI_NewData;
            else
                DI_TempDataArray(:,ColumnChan) = DI_NewData;
            end
            %Clear data from the buffer
            ch.DataIn.Clear;
        end  
        %Display the data in the command window
        disp(DI_TempDataArray)
end

%Stop scanning
myDI2008.AcquisitionStopAsync.Result;

%It is important to disconnect from the device.  If you have connected
%successfully to the device, but do not disconnect you may need to unplug
%your hardware from the USB cable before you can connect again.
myDI2008.Dispose;
DIHardware.Dispose;



 







