%Example program for the DataqSDK.NET control with a DI-245 in MATLAB. 
%Prerequisites: WinDaq software installed, DI-245 hardware installed,
%DInewdata.m file.
%Please submit any questions about this program online at: http://www.dataq.com/support/live-agent/

%Make the .NET DATAQ SDK assembly visible to MATLAB
%The file path for the Dataq.Simple.dll and Dataq.Common.dll will vary
%depending on your OS and installation version.  
%The dll's will only need to be added the first time you run the program
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Simple\v4.0_1.0.0.2__9767f47f9c295223\Dataq.Simple.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Common\v4.0_1.0.0.1__9767f47f9c295223\Dataq.Common.dll');

%View the methods, properties and events of Dataq.Simple
methods Dataq.Simple.DataqDevice
properties Dataq.Simple.DataqDevice
events Dataq.Simple.DataqDevice
%methodsview('Dataq.Simple.DataqDevice')

%Discover connected devices
myDI = Dataq.Simple.Discovery.DiscoverAllDevices;

%Use the first device in the discovery array
DIHardware = myDI(1);

%Connect to the DATAQ Hardware
%If the hardware was not detected you will get an error that the 'Index was
%outside the bounds of the array.'
try
  DIHardware.Connect();
catch ME
  disp(ME.message);
end

%Display the Serial Number, COMPort, and hardware model
disp(DIHardware.SerialNumber)
disp(DIHardware.ComPort)
disp(DIHardware.Model)

%Set up Channels 1-2 for analog voltage measurements
ChannelTypeAnalog = Dataq.Simple.ChannelType.AnalogVoltage;
DIHardware.ChangeChannelType(0, ChannelTypeAnalog);
DIHardware.ChangeChannelType(1, ChannelTypeAnalog);

%Set up Channels 3-4 for thermocouple measurements
ChannelTypeThermocouple = Dataq.Simple.ChannelType.Thermocouple;
DIHardware.ChangeChannelType(2, ChannelTypeThermocouple);
DIHardware.ChangeChannelType(3, ChannelTypeThermocouple);

%Set the Analog Voltage Input Range for Channels 1-2
%ChannelArray.ListOfInputRanges gives the list of the possible input ranges for the channel.
%For example, to set Channel 1 =  50 Volt Range: DIHardware.ChannelArray(1).InputRange = DIHardware.ChannelArray(1).ListOfInputRanges.Item(0);
%Possible input ranges for the Analog Inputs are:
%0 =  50
%1 =  25
%2 =  10
%3 =  5
%4 =  2.5
%5 =  1
%6 =  .5
%7 =  .25
%8 =  .1
%9 =  .05
%10 =  .025
%11 =  .01
DIHardware.ChannelArray(1).InputRange = DIHardware.ChannelArray(1).ListOfInputRanges.Item(2); %2 =  10
DIHardware.ChannelArray(2).InputRange = DIHardware.ChannelArray(2).ListOfInputRanges.Item(5); %5 =  1

%Set the Thermocouple Type for Channels 3-4
%Possible input ranges for the Thermocouple Inputs are: J, K, T, B, R, S, E, N 
TCTypeNameJ = Dataq.Simple.TCTypeName.J;
TCTypeNameK = Dataq.Simple.TCTypeName.K;
DIHardware.ChannelArray(3).TCType = TCTypeNameJ;
DIHardware.ChannelArray(4).TCType = TCTypeNameK;
    
%Enable Channels 1-4
DIHardware.ChannelArray(1).Enabled = true;
DIHardware.ChannelArray(2).Enabled = true;
DIHardware.ChannelArray(3).Enabled = true;
DIHardware.ChannelArray(4).Enabled = true;

%Set up the digital input channel
DIHardware.ChannelArray(9).Enabled = true; 

%Set the Sample Rate
DIHardware.SampleRatePerChannel = 100;
%Display the actual Sample Rate. Note: the class will always select the sampling rate closest to the one selected constrained
%by the number of enabled channels. For a full treatment of how to configure DI-245 sampling rate refer to the instrument's prototocol document:
%http://www.dataq.com/resources/pdfs/support_articles/DI-245-protocol.pdf
disp('Sample Rate Per Channel')
disp(DIHardware.SampleRatePerChannel)

%Set the number of scans to acquire before the NewData event fires.
DIHardware.NewDataMinimum = 40; 

%Create an event listener for the NewData event. 
%This event listener will run the code in the DInewdata.m file each time new data is available after the device is started. 
try
    lh = addlistener(DIHardware,'NewData',@DInewdata);
catch ME
    disp(ME.message);
end

%Start scanning
DIHardware.Start();

%Pause for 5 seconds to collect data.  The pause is used only for
%demonsration in this example file.  Comment out the 'DIHardware.Stop();'
%and 'DIHardware.Disconnect();' lines for continuous data collection and
%then execute these lines from the Command Window when you want to stop scanning.
pause(5);

%Stop scanning
DIHardware.Stop();

%It is important to disconnect from the device.  If you have connected
%successfully to the device, but do not disconnect you may need to unplug
%your hardware from the USB cable before you can connect again.  
DIHardware.Disconnect();



 







